aboutsummaryrefslogtreecommitdiffstats
path: root/test/compilationTests/milestonetracker/MilestoneTracker.sol
diff options
context:
space:
mode:
Diffstat (limited to 'test/compilationTests/milestonetracker/MilestoneTracker.sol')
-rw-r--r--test/compilationTests/milestonetracker/MilestoneTracker.sol4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/compilationTests/milestonetracker/MilestoneTracker.sol b/test/compilationTests/milestonetracker/MilestoneTracker.sol
index 318330df..2f0d58cb 100644
--- a/test/compilationTests/milestonetracker/MilestoneTracker.sol
+++ b/test/compilationTests/milestonetracker/MilestoneTracker.sol
@@ -196,7 +196,7 @@ contract MilestoneTracker {
}
/// @notice `onlyDonor` Approves the proposed milestone list
/// @param _hashProposals The sha3() of the proposed milestone list's
/// bytecode; this confirms that the `donor` knows the set of milestones
/// they are approving
function acceptProposedMilestones(bytes32 _hashProposals
@@ -205,7 +205,7 @@ contract MilestoneTracker {
uint i;
if (!changingMilestones) throw;
- if (sha3(proposedMilestones) != _hashProposals) throw;
+ if (keccak256(proposedMilestones) != _hashProposals) throw;
// Cancel all the unfinished milestones
for (i=0; i<milestones.length; i++) {
@@ -196,7 +196,7 @@ contract MilestoneTracker {
}
/// @notice `onlyDonor` Approves the proposed milestone list
- /// @param _hashProposals The sha3() of the proposed milestone list's
+ /// @param _hashProposals The keccak256() of the proposed milestone list's
/// bytecode; this confirms that the `donor` knows the set of milestones
/// they are approving